{% load inteltool_versioned_static %}

<script src="{% aa_intel_tool_static "aa_intel_tool/javascript/aa-intel-tool-clipboard.min.js" %}"></script>
<script src="{% aa_intel_tool_static "aa_intel_tool/javascript/aa-intel-tool-highlight.min.js" %}"></script>
<script src="{% aa_intel_tool_static "aa_intel_tool/javascript/aa-intel-tool-dscan.min.js" %}"></script>
