# Generated by Django 4.0.10 on 2023-08-09 07:37

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aa_intel_tool", "0003_alter_scandata_scan"),
    ]

    operations = [
        migrations.AlterField(
            model_name="scandata",
            name="section",
            field=models.CharField(
                choices=[
                    ("invalid", "Invalid scan data"),
                    ("pilotlist", "Pilot list"),
                    ("corporationlist", "Corporation list"),
                    ("alliancelist", "Alliance list"),
                    ("shiptypes", "Ship types"),
                    ("shiplist", "Ship list"),
                    ("shiplist_on_grid", "Ship list (on grid)"),
                    ("shiplist_off_grid", "Ship list (off grid)"),
                    ("structures_on_grid", "Structures (on grid)"),
                    ("deployables_on_grid", "Deployables (on grid)"),
                ],
                default="invalid",
                max_length=19,
                verbose_name="The scan section",
            ),
        ),
    ]
