@media all {
    .aa-intel-tool .aa-intel-scan-evetime {
        margin: 1.5rem 0;
    }

    .aa-intel-tool .aa-intel-scan-page-buttons ul li {
        display: block;
        float: left;
        width: 150px;
    }

    .aa-intel-tool .aa-intel-scan-page-buttons ul li > a {
        padding: 0;
    }

    .aa-intel-tool .aa-intel-scan-page-buttons {
        margin-bottom: 1.5rem;
        margin-top: 1rem;
    }

    .aa-intel-tool .aa-intel-scan-page-buttons button {
        position: relative;
        width: 100%;
    }

    .aa-intel-tool .aa-intel-copy-result {
        width: 300px;
    }

    .aa-intel-tool .paste-explanation {
        margin-bottom: 2rem;
    }

    .aa-intel-tool .paste-explanation ul {
        list-style-type: none;
        padding: 0;
    }

    .aa-intel-tool .paste-explanation li > small {
        color: rgb(119 119 119);
    }

    .aa-intel-tool td.data-align-right {
        text-align: right;
    }

    .aa-intel-tool .aa-intel-section-header {
        border-bottom: 1px solid rgb(237 237 237);
        margin-bottom: 2rem;
        margin-top: 2rem;
    }

    .aa-intel-tool .aa-intel-section-header .aa-intel-section-title {
        font-size: 1.25em;
    }

    .aa-intel-tool .aa-intel-alliance-logo-wrapper,
    .aa-intel-tool .aa-intel-corporation-logo-wrapper,
    .aa-intel-tool .aa-intel-pilot-avatar-wrapper,
    .aa-intel-tool .aa-intel-ship-image-wrapper {
        display: inline-block;
        margin-right: 0.5rem;
    }

    .aa-intel-tool .aa-intel-alliance-information-wrapper,
    .aa-intel-tool .aa-intel-corporation-information-wrapper,
    .aa-intel-tool .aa-intel-pilot-information-wrapper {
        display: inline-block;
        vertical-align: top;
    }

    .aa-intel-tool .aa-intel-alliance-id-1 .aa-intel-alliance-information-wrapper {
        vertical-align: inherit;
    }

    .aa-intel-tool .aa-intel-alliance-name-wrapper,
    .aa-intel-tool .aa-intel-alliance-links-wrapper,
    .aa-intel-tool .aa-intel-corporation-name-wrapper,
    .aa-intel-tool .aa-intel-corporation-links-wrapper,
    .aa-intel-tool .aa-intel-pilot-name-wrapper,
    .aa-intel-tool .aa-intel-pilot-links-wrapper {
        display: block;
    }
}

/* Highlighting
------------------------------------------------------------------------------------- */
@media all {
    .aa-intel-tool .aa-intel-highlight,
    .aa-intel-tool .aa-intel-highlight-sticky {
        background-color: rgba(255 255 255 / 50%);
    }

    .aa-intel-tool .aa-intel-highlight td:first-child,
    .aa-intel-tool .aa-intel-highlight-sticky td:first-child {
        border-left: 1px solid rgb(255 0 0);
        margin-left: -11px;
        padding-left: 4px;
    }
}

/* Form
------------------------------------------------------------------------------------- */
@media all {
    .aa-intel-tool .form-submit-area div:first-child {
        margin-bottom: 15px;
    }

    .aa-intel-tool .aa-intel-form-submitted-info {
        display: none;
    }

    .aa-intel-tool form.is-submitting .aa-intel-form-submitted-info {
        display: block;
    }
}

/* Data Tables
------------------------------------------------------------------------------------- */
@media all {
    .aa-intel-tool div.dataTables_wrapper div.dataTables_info {
        padding-top: 8px;
        white-space: initial;
    }

    .aa-intel-tool .dataTables_wrapper table.dataTable {
        width: 100%;
    }

    .aa-intel-tool .dataTable tr.even {
        background-color: rgba(236 240 241 / 35%);
    }

    .template-dark-mode .aa-intel-tool .dataTable tr.even {
        background-color: rgba(236 240 241 / 5%);
    }

    .aa-intel-tool .dataTable tbody tr:hover,
    .aa-intel-tool .dataTable tbody tr.aa-intel-highlight,
    .aa-intel-tool .dataTable tbody tr.aa-intel-highlight-sticky {
        background-color: rgba(198 200 200 / 50%);
    }

    .template-dark-mode .aa-intel-tool .dataTable tbody tr:hover,
    .template-dark-mode .aa-intel-tool .dataTable tbody tr.aa-intel-highlight,
    .template-dark-mode .aa-intel-tool .dataTable tbody tr.aa-intel-highlight-sticky {
        background-color: rgba(236 240 241 / 10%);
    }

    .aa-intel-tool .table-aa-intel tbody > tr > td {
        vertical-align: middle;
    }

    .aa-intel-tool .table-no-images > tbody > tr > td {
        padding-bottom: 12px;
        padding-top: 11px;
    }

    .aa-intel-tool .table-sortable > tbody > tr > .table-data-count {
        padding-right: 1rem;
        text-align: right;
    }

    .aa-intel-tool td.text-ellipsis {
        max-width: 50px;
        white-space: nowrap;
    }

    .aa-intel-alliance-information-wrapper,
    .aa-intel-corporation-information-wrapper,
    .aa-intel-pilot-information-wrapper {
        max-width: calc(100% - 35px);
    }

    .aa-intel-alliance-name-wrapper,
    .aa-intel-corporation-name-wrapper,
    .aa-intel-pilot-name-wrapper {
        overflow: hidden;
        text-overflow: ellipsis;
    }

    .aa-intel-tool td.fix-eve-image-position > span:first-child {
        position: relative;
        transform: translateY(16%);
    }

    .aa-intel-tool td.fix-eve-image-position > span.alliance-id-1 {
        transform: none;
    }
}

/* Callouts
 *
 * Not quite alerts, but custom and helpful notes for folks reading the docs.
 * Requires a base and modifier class.
------------------------------------------------------------------------------------- */
@media all {
    /* Common styles for all types */
    .aa-intel-tool .bs-callout {
        border: 1px solid rgb(238 238 238);
        border-left-width: 5px;
        border-radius: 3px;
        margin: 20px 0;
        padding: 20px;
    }

    .aa-intel-tool .bs-callout h4 {
        margin-bottom: 5px;
        margin-top: 0;
    }

    .aa-intel-tool .bs-callout p:last-child {
        margin-bottom: 0;
    }

    .aa-intel-tool .bs-callout code {
        border-radius: 3px;
    }

    /* Tighten up space between multiple callouts */
    .aa-intel-tool .bs-callout + .bs-callout {
        margin-top: -5px;
    }

    /* Variations */
    .aa-intel-tool .bs-callout-danger {
        border-left-color: rgb(206 72 68);
    }

    .aa-intel-tool .bs-callout-danger h4 {
        color: rgb(206 72 68);
    }

    .aa-intel-tool .bs-callout-warning {
        border-left-color: rgb(170 103 8);
    }

    .aa-intel-tool .bs-callout-warning h4 {
        color: rgb(170 103 8);
    }

    .aa-intel-tool .bs-callout-info {
        border-left-color: rgb(27 128 158);
    }

    .aa-intel-tool .bs-callout-info h4 {
        color: rgb(27 128 158);
    }
}

/* Footer
------------------------------------------------------------------------------------- */
@media all {
    .aa-intel-tool .aa-intel-tool-footer {
        border-top: 1px solid rgb(236 240 241);
        font-size: 85%;
        margin-top: 1rem;
        padding-top: 1rem;
    }

    .template-dark-mode .aa-intel-tool .aa-intel-tool-footer {
        border-color: rgb(70 69 69);
    }
}
