{% load i18n %}

<script>
    const aaIntelToolJsL10n = {
        copyToClipboard: {
            permalink: {
                text: {
                    success: '{% translate "Permalink successfully copied" %}',
                    error: '{% translate "Something went wrong. Nothing copied. Maybe your browser does not support this function." %}'
                }
            }
        },
        scanData: {
            empty: '{% translate "Unaffiliated / No Alliance" %}',
            npcCorp: '{% translate "NPC Corp" %}',
        },
        dataTables: {
            translation: {
                decimal: '{% translate "," context "Decimal separator" %}',
                thousands: '{% translate "." context "Thousands separator" %}',
                emptyTable: '{% translate "No data available in this table" %}',
                info: '{% translate "Showing _END_ entries" context "Keep _END_ as it is. It will be replaced by a number." %}',
                infoFiltered: '{% translate "(filtered from _MAX_ total entries)" context "Keep _MAX_ as it is. It will be replaced by a number." %}',
                infoEmpty: '{% translate "No records available" %}',
                infoPostFix: '',
                lengthMenu: '{% translate "Show _MENU_" context "Keep _MENU_ as it is. It will be replaced by an HTML construct." %}',
                loadingRecords: '{% translate "Loading …" %}',
                processing: '{% translate "Processing …" %}',
                zeroRecords: '{% translate "Nothing found, sorry …" %}',
                search: '_INPUT_',
                searchPlaceholder: '{% translate "Search …" %}',
                paginate: {
                    first: '{% translate "First" %}',
                    last: '{% translate "Last" %}',
                    next: '{% translate "Next" %}',
                    previous: '{% translate "Previous" %}'
                },
                aria: {
                    sortAscending: '{% translate ": activate to sort column ascending" %}',
                    sortDescending: '{% translate ": activate to sort column descending" %}',
                }
            }
        }
    };
</script>
