# Generated by Django 4.0.10 on 2023-08-04 15:02

# Django
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Scan",
            fields=[
                (
                    "hash",
                    models.CharField(
                        editable=False,
                        max_length=30,
                        primary_key=True,
                        serialize=False,
                        unique=True,
                        verbose_name="The hash of the scan.",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        auto_now_add=True,
                        db_index=True,
                        verbose_name="Date and time the scan was created.",
                    ),
                ),
                ("raw_data", models.TextField(verbose_name="The original scan data.")),
                (
                    "processed_data",
                    models.JSONField(
                        default=dict, verbose_name="The processed scan data."
                    ),
                ),
                (
                    "scan_type",
                    models.CharField(
                        choices=[
                            ("invalid", "Invalid scan data"),
                            ("dscan", "D-Scan"),
                            ("fleetcomp", "Fleet Composition"),
                            ("chatlist", "Chat List"),
                        ],
                        default="invalid",
                        max_length=9,
                        verbose_name="The scan type.",
                    ),
                ),
            ],
            options={
                "verbose_name": "scan",
                "verbose_name_plural": "scans",
                "default_permissions": (),
            },
        ),
    ]
