# Generated by Django 4.0.10 on 2023-08-06 09:03

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aa_intel_tool", "0001_initial"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="scan",
            name="processed_data",
        ),
        migrations.CreateModel(
            name="ScanData",
            fields=[
                (
                    "id",
                    models.AutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "section",
                    models.CharField(
                        choices=[
                            ("invalid", "Invalid scan data"),
                            ("pilotlist", "Pilot list"),
                            ("corporationlist", "Corporation list"),
                            ("alliancelist", "Alliance list"),
                        ],
                        default="invalid",
                        max_length=15,
                        verbose_name="The scan section",
                    ),
                ),
                (
                    "processed_data",
                    models.JSONField(
                        default=dict, verbose_name="The processed scan section data"
                    ),
                ),
                (
                    "scan",
                    models.ForeignKey(
                        blank=True,
                        default=None,
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="scan_data",
                        to="aa_intel_tool.scan",
                        verbose_name="Scan",
                    ),
                ),
            ],
            options={
                "verbose_name": "scan data",
                "verbose_name_plural": "scan data",
                "default_permissions": (),
            },
        ),
    ]
