{% load i18n %}
{% load bootstrap %}

<div class="panel panel-default">
    <div class="panel-body">
        <div class="row">
            <div class="col-lg-4">
                <div class="paste-explanation">
                    <header class="entry-header">
                        <h2 class="entry-title">{% translate "What can I paste?" %}</h2>
                    </header>

                    <ul>
                        {% if app_settings.INTELTOOL_ENABLE_MODULE_DSCAN %}
                            <li>» {% translate "D-Scan" %} </li>
                        {% endif %}

                        {% if app_settings.INTELTOOL_ENABLE_MODULE_CHATSCAN %}
                            <li>
                                » {% translate "Chat Member List" %}

                                {% if app_settings.INTELTOOL_CHATSCAN_MAX_PILOTS > 0 %}
                                    <small>
                                        ({% blocktranslate count max_pilots=app_settings.INTELTOOL_CHATSCAN_MAX_PILOTS %}Limited to a maximum of {{ max_pilots }} pilot per scan.{% plural %}Limited to a maximum of {{ max_pilots }} pilots per scan.{% endblocktranslate %})
                                    </small>
                                {% endif %}
                            </li>
                        {% endif %}

                        {% if app_settings.INTELTOOL_ENABLE_MODULE_FLEETCOMP %}
                            <li>» {% translate "Fleet Composition" %}</li>
                        {% endif %}
                    </ul>
                </div>
            </div>

            <div class="col-lg-8">
                <form id="new_intel" name="new_intel" method="post" action="/intel/">
                    {% csrf_token %}

                    {{ form|bootstrap }}

                    <div class="row form-submit-area">
                        <div class="col-sm-2">
                            <button type="submit" class="btn btn-primary" name="submit-form">
                                {% translate "Submit" %}
                            </button>
                        </div>

                        <div class="col-sm-12 aa-intel-form-submitted-info">
                            <div class="bs-callout bs-callout-info">
                                <p>{% translate "Working on it, please be patient …" %}</p>
                                <ul>
                                    <li>{% translate "Detecting the intel type" %}</li>
                                    <li>{% translate "Fetching potentially missing information from ESI (this might take a moment)" %}</li>
                                    <li>{% translate "Parsing data" %}</li>
                                </ul>
                            </div>
                        </div>
                    </div>
                </form>
            </div>
        </div>
    </div>
</div>
