{% load i18n %}

{% translate "Unaffiliated / No Alliance" as no_alliance %}

<div class="col-md-12 col-lg-6 aa-intel-chatscan-pilots">
    <header class="aa-intel-section-header">
        <h2 class="aa-intel-section-title">
            {% translate "Pilots Breakdown" %} (<span id="aa-intel-pilots-count">0</span>)
        </h2>
    </header>

    <div class="panel panel-default">
        <div class="panel-body">
            <div class="table-local-scan table-local-scan-pilots table-aa-intel">
                <table class="table table-sortable table-condensed aa-intel-pilot-participation-list" style="width: 100%;">
                    <thead>
                        <tr>
                            <th>{% translate "Name" %}</th>
                            <th>{% translate "Alliance" %}</th>
                            <th>{% translate "Corporation" %}</th>
                        </tr>
                    </thead>
                </table>
            </div>
        </div>
    </div>
</div>
