# Generated by Django 4.0.10 on 2023-08-06 09:21

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("aa_intel_tool", "0002_remove_scan_processed_data_scandata"),
    ]

    operations = [
        migrations.AlterField(
            model_name="scandata",
            name="scan",
            field=models.ForeignKey(
                blank=True,
                default=None,
                null=True,
                on_delete=django.db.models.deletion.CASCADE,
                related_name="scan_data",
                to="aa_intel_tool.scan",
                verbose_name="Scan",
            ),
        ),
    ]
