{% load i18n %}

<div class="col-md-4 col-sm-6 col-lg-3">
    <header class="aa-intel-section-header">
        <h2 class="aa-intel-section-title">
            {% translate "Ship Types" %}
        </h2>
    </header>

    <div class="panel panel-default">
        <div class="panel-body">
            <div class="table-local-dscan table-local-dscan-ship-classes-{{ dscan_section }} table-aa-intel">
                <table class="table table-condensed table-sortable table-no-images aa-intel-dscan-ship-types aa-intel-dscan-ship-types-list" style="width: 100%;">
                    <thead>
                    <tr>
                        <th>{% translate "Ship Type" %}</th>
                        <th>{% translate "Count" %}</th>
                    </tr>
                    </thead>
                </table>
            </div>
        </div>
    </div>
</div>
